@@ -84,7 +84,7 @@ $ITEM_PATTERN = qr/$field\t$field\t$field\t$field(?:\t$field)?/;
 	0   => 'text file',
 	1   => 'Gopher menu',
 	2   => 'CCSO nameserver',
-	3   => 'error',
+	3   => 'Gopher error',
 	4   => 'binhexed Macintosh file',
 	5   => 'DOS binary archive',
 	6   => 'Unix uuencoded file',
